---
name: Bug report
about: Create a report to help us reproduce and fix a bug
title: 'BUG:'
labels: BUG
assignees: ''

---

#### Before submitting a bug, please make sure the issue hasn't been already addressed by searching through [the past issues](https://github.com/NickleDave/vak/issues)

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

Please include specific commands entered and complete error messages. More specific detail is better.  
Please format code so it easy to read e.g. using triple backticks in [GitHub-flavored Markdown](https://docs.github.com/en/github/writing-on-github/getting-started-with-writing-and-formatting-on-github/basic-writing-and-formatting-syntax#quoting-code)

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Desktop (please complete the following information):**
 - Operating System: [Linux, Windows, Mac]
 - Version [e.g. 22]. You can determine this in Python by running `vak.__version__`

**Additional context**
Add any other context about the problem here.
